aboutsummaryrefslogtreecommitdiff
path: root/include/ns16550.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/ns16550.h')
-rw-r--r--include/ns16550.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/include/ns16550.h b/include/ns16550.h
index 08e933ffe79..bef29610325 100644
--- a/include/ns16550.h
+++ b/include/ns16550.h
@@ -56,7 +56,7 @@ enum ns16550_flags {
};
/**
* struct ns16550_platdata - information about a NS16550 port
*
* @base: Base register address
* @reg_width: IO accesses size of registers (in bytes, 1 or 4)
@@ -67,7 +67,7 @@ enum ns16550_flags {
* @flags: A few flags (enum ns16550_flags)
* @bdf: PCI slot/function (pci_dev_t)
*/
-struct ns16550_platdata {
+struct ns16550_plat {
unsigned long base;
int reg_width;
int reg_shift;
@@ -111,7 +111,7 @@ struct NS16550 {
UART_REG(ssr); /* 11*/
#endif
#ifdef CONFIG_DM_SERIAL
- struct ns16550_platdata *plat;
+ struct ns16550_plat *plat;
#endif
};
@@ -56,7 +56,7 @@ enum ns16550_flags {
};
/**
- * struct ns16550_platdata - information about a NS16550 port
+ * struct ns16550_plat - information about a NS16550 port
*
* @base: Base register address